Strava
------

Register your OAuth2 app in api settings page:

    https://strava.com/settings/api

In this page you will get your key and secret

Development callback URL (only the domain is required on strava.com/settings/api)

    http://example.com/accounts/strava/login/callback/

For more information:
Strava auth documentation: https://developers.strava.com/docs/authentication/
API documentation: https://developers.strava.com/docs/reference/
